
      subroutine autocorr
c******************************************************************************
c     This routine autocorrelates an observed spectrum with itself in order
c     to get information on line widths and to look for binaries
c******************************************************************************
c     obswave = wavelength array
c     obsflux = flux array
c     nobspts = number of points in spectrum
c     wavelo, wavehi are wavelength limits to be considered in calculation

      implicit real*8 (a-h,o-z)
      include 'obsquants.com'
      include 'asciichars.com'


c*****set up some parameters; some of these are temporary
      maxshift = 35
      ndeg = 4
      halfpower = 0.5
      linetype = 1
      linenum = 1
      

c*****find array subscripts for minimum and maximum wavelengths to be used;
c*****compute the dispersion just for the region under consideration;
c*****the autocorrelation will be done for shifts up to "maxshift" pixels
      call findlimits (obswave, nobspts, wavelo, wavehi, ilo, ihi)
      itot = ihi - ilo + 1
      displocal = (obswave(ihi) - obswave(ilo))/dble(itot)


c*****autocorrelate the spectrum fluxes with themselves, shifting the
c*****spectrum array up to +/-maxshift
      do j=1,maxshift+1
         call correlate (obsflux(ilo), obsflux(ilo-1+j), itot, rxy(j))
         waveshift(j) = (j-1)*displocal
      enddo


c*****find the half-power wavelength shift at (upper) half-power point
      do j =1,maxshift+1
         if (rxy(j).lt.0.5 .and. j.ge.ndeg) exit
      enddo
      jwave = j - 3
      call lagrange (ndeg, rxy(jwave), waveshift(jwave),
     .               halfpower, halfwave)
      corrhalf = 0.8
      halfvel = 3.d5*corrhalf*halfwave/((wavelo+wavehi)/2.)


c*****double these values for full width instead of half width
      halfwave2 = 2.*halfwave
      halfvel2 = 2.*halfvel
          write (99,1001) wavelo, wavehi, halfwave2, halfvel2


c*****exit normally
      return


c*****format statements
1001  format ('LAMBDA RANGE: ', 2f7.1, '  AUTODCORR  FWHM: ',
     .         f6.3, f6.1, ' (A, km/sec)')
      end



