
      subroutine lagrange (ndeg, xarray, yarray, xpoint, ypoint)
c***********************************************************************
c     this routine produces a Lagrange n-point interpolation; see e.g.,
C         http://mathworld.wolfram.com/LagrangeInterpolatingPolynomial.html
c     where:    ndeg    = the number of points used for the polynomial
c               xarray  = the independent variable data array
c               yarray  = the dependent variable data array
c               xpoint  = the x position for desired interpolation
c               ypoint  = the interpolated y value
c***********************************************************************

      implicit real*8 (a-h,o-z)
      real*8 xarray(*), yarray(*)


c*****first check to be sure that that the desired interpolation
c*****xpoint is within the xarray bounds
      if (xarray(1) .lt. xarray(ndeg)) then
         ilo = 1
         ihi = ndeg
      else
         ilo = ndeg
         ihi = 1
      endif
      if (xpoint.lt.xarray(ilo) .or. xpoint.gt.xarray(ihi)) then
         write (99,1001) xpoint, xarray(1), xarray(ndeg)
         ypoint = -9999.
         return
      endif


c*****now do the interpolation
      ptot = 0.
      do j=1,ndeg
         xfrac = 1.
         do k=1,ndeg
            if (k .eq. j) cycle
            xfrac = xfrac*(xpoint-xarray(k))/(xarray(j)-xarray(k))
         enddo
         pj = yarray(j)*xfrac
         ptot = ptot + pj
      enddo
      ypoint = ptot
      return


c*****format statements
1001        format ('lagrange: independent variable for interpolation ',
     .              '= ', 1pd12.5/'is beyond array limits: ', 2d13.5)


      end
         




