
      subroutine obsstats
c******************************************************************************
c     this routine does simple mean and standard deviation statistics,
c     doing a second pass with elimination of the points that are
c     more than *sigmaclip* times the first-pass $sigmas$ valuue
c******************************************************************************

      implicit real*8 (a-h,o-z)
      include 'obsquants.com'
      include 'asciichars.com'


c*****do the statistics in many small spectral intervals
      write (99,1001)
      do kountwave=1,126
         if     (kountwave .eq. 121) then
            wavelo = 5156.0
            wavehi = 5160.0
         elseif (kountwave .eq. 122) then
            wavelo = 5175.0
            wavehi = 5181.0
         elseif (kountwave .eq. 123) then
            wavelo = 5286.0
            wavehi = 5295.0
         elseif (kountwave .eq. 124) then
            wavelo = 4502.0
            wavehi = 4506.0
         elseif (kountwave .eq. 125) then
            wavelo = 4510.5
            wavehi = 4514.0
         elseif (kountwave .eq. 126) then
            wavelo = 4640.0
            wavehi = 4645.0
         else
            wavelo = 4500. + (kountwave-1)*20.
            wavehi = wavelo + 20.
         endif
         call findlimits (obswave, nobspts, wavelo, wavehi, ilo, ihi)
         itot = ihi - ilo + 1


c*****first pass
         average = 0.
         do i=ilo,ihi
            average = average + obsflux(i)
         enddo
         average = average/itot
         stddev = 0.
         do i=ilo,ihi
            stddev = stddev + (obsflux(i)-average)**2
         enddo
         stddev = dsqrt(stddev/(itot-1))
         nstats(1,kountwave) = itot
         avgflux(1,kountwave) = average
         sigflux(1,kountwave) = stddev


c*****identify the outliers
         tolerance = sigmaclip*stddev
         do i=ilo,ihi
            if (dabs(obsflux(i)-average) .gt. tolerance) then
               badpix(i) = 1
c               write (99,1002) sigmaclip, obswave(i), obsflux(i)
            else
               badpix(i) = 0
            endif
         enddo


c*****second pass
         average = 0.
         nretain = 0
         do i=ilo,ihi
            if (badpix(i) .eq. 0) then
               nretain = nretain + 1
               average = average + obsflux(i)
            endif
         enddo
         average = average/nretain
         stddev = 0.
         do i=ilo,ihi
            if (badpix(i) .eq. 0) then
               stddev = stddev + (obsflux(i)-average)**2
            endif
         enddo
         stddev = dsqrt(stddev/(nretain-1))
         nstats(2,kountwave) = nretain
         avgflux(2,kountwave) = average
         sigflux(2,kountwave) = stddev


c*****print summary statistics
         write (99,1003) (wavelo+wavehi)/2., 
     .                   (avgflux(i,kountwave),sigflux(i,kountwave),
     .                   nstats(i,kountwave),i=1,2)
      enddo


c*****create continuum normalizations for blue and yellow regions
      contnormblu = (avgflux(2,124)+avgflux(2,125)+avgflux(2,126))/3.
      contnormyel = (avgflux(2,121)+avgflux(2,122)+avgflux(2,123))/3.
      write (99,1004) contnormblu, contnormyel


c*****exit normally
      return


c*****format statemnets
1001  format (/'OBSERVED SPECTRUM STATISTICS'/
     .        'mean lambda     raw avg   sigma  num',
     .        '   clean avg   sigma  num')
1002  format (f5.2, ' sigma outlier: ', f10.3, f6.3)
1003  format (f11.1, 2(4x, f8.3, f8.3, i5))
1004  format ('blue and yellow continuum levels: ', 2f9.3)


      end





