
c***********************************************************************
      subroutine obssynplot
c***********************************************************************
c     this routine makes an observed/synthetic plot for a spectral region

      implicit real*8 (a-h,o-z)
      include 'asciichars.com'
      include 'obsquants.com'
      include 'synquants.com'
      include 'plotquants.com'
      include 'plotchars.com'


c*****open the plot file and set some general sm variables
      isyn = nchi2nomin(ichi2)
      call blankstring (suffix)
      if     (isyn .ge. 100) then
         write (suffix,1004) isyn
      elseif (isyn .ge. 10) then
         write (suffix,1003) isyn
      else
         write (suffix,1002) isyn
      endif
      call resetplotpars
      ygutter = 0.25
      call triggerplot

      jtot = nsynpts(isyn)
      jpart = jtot/6


c*****write out some global stuff pertaining to all plots
      numywin = 1
      expandval = 0.9
      weightval = 3
      numxlab = 16
      xlab = 'Wavelength (\\AA)'
      numylab = 13
      ylab = 'Relative Flux'
      lableft = 4
      labright = 4
      lablow = 4
      labhigh = 4
      call startplot
      expandval = 0.6
      numorient = 5
      xpoint = 0.50
      ypoint = 1.015
      write (anylabel,1001) nint(teffmod(isyn)), loggmod(isyn), 
     .                      metalmod(isyn), vmicromod(isyn)
      call infoplot
      anylabel = starname
      ypoint = 1.035
      call infoplot 


c*****set parameters for all plots
      orientation = 'portrait '
      numywin = 30
      expandval = 0.6
      numxlab = 7
      xlab = 'nolabel'
      numylab = 7
      ylab = 'nolabel'
      lableft = 2
      lablow = 1
      labright = 0
      labhigh = 0
      wavelo = synwave(isyn,1)
      wavehi = synwave(isyn,jtot)
      call findlimits (obswave, nobspts, wavelo, wavehi, ilo, ihi)
      deepestobs = 1000.
      do i=ilo, ihi
         if (obsflux(i) .lt. deepestobs) 
     .       deepestobs = obsflux(i)
      enddo
      ymin = 0.95*deepestobs
      ymax = +1.45


c*****make plots of observed, synthetic, and O-C in 6 pieces
      do n=1,6
         nywin1 = 5*(n-1) + 1
         nywin2 = 5*(n-1) + 5
         ilo = jpart*(n-1) + 1
         ihi = jpart*(n-1) + jpart
         wavelo = synwave(isyn,ilo)
         wavehi = synwave(isyn,ihi)
         xmin = wavelo
         xmax = wavehi
         smallxtick = -1000.
         largextick = -1000.
         smallytick = -1000.
         largeytick = -1000.
         weightval = 3
         call startplot


c*****plot the synthetic spectrum
         linepoints = 'line  '
         do j=1,jpart
            jpt = ilo + j - 1
            xpos(j) = synwave(isyn,jpt)
            ypos(j) = synflux(isyn,jpt)
         enddo
         numpts = jpart
         weightval = 6
         color = 'red'
         call arrayplot


c*****plot the O-C array
         do j=1,jpart
            jpt = ilo + j - 1
            ypos(j) = obssyndiff(isyn,jpt) + 1.3
         enddo
         weightval = 2.0
         color = 'blue'
         numpts = jpart -10
         call arrayplot


c*****plot the observed spectrum
         wavelo = synwave(isyn,1)
         wavehi = synwave(isyn,jtot)
         call findlimits (obswave, nobspts, wavelo, wavehi, ilo, ihi)
         numpts = ihi - ilo + 1
         do j=1,numpts
            xpos(j) = obswave(ilo+j-1)
            ypos(j) = obsflux(ilo+j-1)
         enddo
         color = 'black'
         weightval = 2.0
         call arrayplot
      enddo

c*****finish plot and end normally
      call finishplot
      return


c*****format statements
1001  format ('Teff=', i5, '   log(g)=', f5.2, '   [M/H]=', f6.2,
     .        '   vmicro=', f6.2)
1002  format ('.', i1, '.ps')
1003  format ('.', i2, '.ps')
1004  format ('.', i3, '.ps')


      end



